Documentation for MiniBot!
===========================

 .. |docs| image:: https://readthedocs.org/projects/minibot/badge/?version=latest
 .. |minibot| image:: https://img.shields.io/badge/minibot-OK-brightgreen.svg

|docs| |minibot|

- Minibot RTD : https://minibot.readthedocs.io

Installation
=============

 python3 -m pip install minilib
